package betterquesting.api2.client.gui.panels.content;

import betterquesting.api.utils.RenderUtils;
import betterquesting.api2.client.gui.controls.IValueIO;
import betterquesting.api2.client.gui.controls.io.ValueFuncIO;
import betterquesting.api2.client.gui.misc.GuiRectangle;
import betterquesting.api2.client.gui.misc.IGuiRect;
import betterquesting.api2.client.gui.panels.IGuiPanel;
import java.util.List;
import net.minecraft.entity.Entity;
import net.minecraft.util.MathHelper;
import org.lwjgl.opengl.GL11;

/* loaded from: betterquesting_api2_client_gui_panels_content.jar:betterquesting/api2/client/gui/panels/content/PanelEntityPreview.class */
public class PanelEntityPreview implements IGuiPanel {
    private final IGuiRect transform;
    public Entity entity;
    private boolean enabled = true;
    private float zDepth = 100.0f;
    private final IValueIO<Float> basePitch = new ValueFuncIO(() -> {
        return Float.valueOf(15.0f);
    });
    private IValueIO<Float> pitchDriver = this.basePitch;
    private final IValueIO<Float> baseYaw = new ValueFuncIO(() -> {
        return Float.valueOf(-30.0f);
    });
    private IValueIO<Float> yawDriver = this.baseYaw;

    public PanelEntityPreview(IGuiRect rect, Entity entity) {
        this.transform = rect;
        this.entity = entity;
    }

    public PanelEntityPreview setRotationFixed(float pitch, float yaw) {
        this.pitchDriver = this.basePitch;
        this.yawDriver = this.baseYaw;
        this.basePitch.writeValue(Float.valueOf(pitch));
        this.baseYaw.writeValue(Float.valueOf(yaw));
        return this;
    }

    public PanelEntityPreview setRotationDriven(IValueIO<Float> pitch, IValueIO<Float> yaw) {
        this.pitchDriver = pitch == null ? this.basePitch : pitch;
        this.yawDriver = yaw == null ? this.baseYaw : yaw;
        return this;
    }

    public PanelEntityPreview setDepth(float z) {
        this.zDepth = z;
        return this;
    }

    public void setEntity(Entity entity) {
        this.entity = entity;
    }

    public void initPanel() {
    }

    public void setEnabled(boolean state) {
        this.enabled = state;
    }

    public boolean isEnabled() {
        return this.enabled;
    }

    public IGuiRect getTransform() {
        return this.transform;
    }

    public void drawPanel(int mx, int my, float partialTick) {
        if (this.entity == null) {
            return;
        }
        IGuiRect bounds = getTransform();
        GL11.glPushMatrix();
        RenderUtils.startScissor(new GuiRectangle(bounds));
        GL11.glColor4f(1.0f, 1.0f, 1.0f, 1.0f);
        int sizeX = bounds.getWidth();
        int sizeY = bounds.getHeight();
        float scale = Math.min((sizeY / 2.0f) / this.entity.field_70131_O, (sizeX / 2.0f) / this.entity.field_70130_N);
        RenderUtils.RenderEntity(bounds.getX() + (sizeX / 2), bounds.getY() + (sizeY / 2) + MathHelper.func_76123_f((this.entity.field_70131_O * scale) / 2.0f), (int) scale, ((Float) this.yawDriver.readValue()).floatValue(), ((Float) this.pitchDriver.readValue()).floatValue(), this.entity);
        RenderUtils.endScissor();
        GL11.glPopMatrix();
    }

    public boolean onMouseClick(int mx, int my, int click) {
        return false;
    }

    public boolean onMouseRelease(int mx, int my, int click) {
        return false;
    }

    public boolean onMouseScroll(int mx, int my, int scroll) {
        return false;
    }

    public boolean onKeyTyped(char c, int keycode) {
        return false;
    }

    public List<String> getTooltip(int mx, int my) {
        return null;
    }
}
